==> kmymoney_5.1.1.orig.tar.xz: kmymoney-5.1.1/kmymoney/plugins/ofx/import/ofximporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "acejones@users.sourceforge.net,ipwizard@users.sourceforge.net",
                "Name": "Ace Jones,Thomas Baumgart",
                "Name[ca@valencia]": "Ace Jones,Thomas Baumgart",
                "Name[ca]": "Ace Jones,Thomas Baumgart",
                "Name[de]": "Ace Jones,Thomas Baumgart",
                "Name[en_GB]": "Ace Jones,Thomas Baumgart",
                "Name[es]": "Ace Jones,Thomas Baumgart",
                "Name[et]": "Ace Jones, Thomas Baumgart",
                "Name[eu]": "Ace Jones,Thomas Baumgart",
                "Name[fi]": "Ace Jones, Thomas Baumgart",
                "Name[fr]": "Ace Jones,Thomas Baumgart",
                "Name[gl]": "Ace Jones,Thomas Baumgart",
                "Name[ia]": "Ace Jones,Thomas Baumgart",
                "Name[it]": "Ace Jones,Thomas Baumgart",
                "Name[ko]": "Ace Jones,Thomas Baumgart",
                "Name[nl]": "Ace Jones,Thomas Baumgart",
                "Name[pl]": "Ace Jones,Thomas Baumgart",
                "Name[pt]": "Ace Jones,Thomas Baumgart",
                "Name[pt_BR]": "Ace Jones,Thomas Baumgart",
                "Name[ru]": "Ace Jones,Thomas Baumgart",
                "Name[sk]": "Ace Jones,Thomas Baumgart",
                "Name[sv]": "Ace Jones,Thomas Baumgart",
                "Name[uk]": "Ace Jones,Thomas Baumgart",
                "Name[x-test]": "xxAce Jones,Thomas Baumgartxx"
            }
        ],
        "Description": "Add OFX importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des d'OFX al KMyMoney",
        "Description[ca]": "Afegeix la importació des d'OFX al KMyMoney",
        "Description[de]": "Fügt OFX-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add OFX importing to KMyMoney",
        "Description[es]": "Añade importación OFX a KMyMoney",
        "Description[et]": "KMyMoney OFX importimine",
        "Description[eu]": "OFX inportazioa gehitzen dio KMyMoneyri ",
        "Description[fi]": "Lisää OFX-tuonti KMyMoney-ohjelmaan",
        "Description[fr]": "Ajoute l'importation « OFX » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar OFX en KMyMoney",
        "Description[it]": "Aggiunge l'importazione OFX a KMymoney",
        "Description[ko]": "KMyMoney에 OFX 가져오기 추가",
        "Description[nl]": "Voeg OFX importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie OFX do KMyMoney",
        "Description[pt]": "Adição da importação de OFX para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação OFX no KMyMoney",
        "Description[sk]": "Pridať OFX import do KMyMoney",
        "Description[sv]": "Lägg till OFX-import till KMyMoney",
        "Description[uk]": "Імпортування даних OFX у KMyMoney",
        "Description[x-test]": "xxAdd OFX importing to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "ofximporter",
        "License": "GPL",
        "Name": "OFX Importer",
        "Name[ca@valencia]": "Importador d'OFX",
        "Name[ca]": "Importador d'OFX",
        "Name[cs]": "Importér OXF",
        "Name[de]": "OFX-Import",
        "Name[en_GB]": "OFX Importer",
        "Name[es]": "Importador OFX",
        "Name[et]": "OFX importija",
        "Name[eu]": "OFX inportatzailea",
        "Name[fi]": "OFX-tuoja",
        "Name[fr]": "Importateur OFX",
        "Name[gl]": "Importador de OFX",
        "Name[ia]": "Importator de OFX",
        "Name[it]": "Strumento di importazione OFX",
        "Name[ko]": "OFX 가져오기 도구",
        "Name[nl]": "QFX-importeren",
        "Name[pl]": "Importer OFX",
        "Name[pt]": "Importação de OFX",
        "Name[pt_BR]": "Importador OFX",
        "Name[ru]": "Импорт OFX",
        "Name[sk]": "OFX Importer",
        "Name[sv]": "QFX-import",
        "Name[uk]": "Інструмент імпортування OFX",
        "Name[x-test]": "xxOFX Importerxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/ofx/import/ofximporter.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "acejones@users.sourceforge.net,ipwizard@users.sourceforge.net",
                "Name": "Ace Jones,Thomas Baumgart",
                "Name[ca@valencia]": "Ace Jones,Thomas Baumgart",
                "Name[ca]": "Ace Jones,Thomas Baumgart",
                "Name[de]": "Ace Jones,Thomas Baumgart",
                "Name[en_GB]": "Ace Jones,Thomas Baumgart",
                "Name[es]": "Ace Jones,Thomas Baumgart",
                "Name[et]": "Ace Jones, Thomas Baumgart",
                "Name[eu]": "Ace Jones,Thomas Baumgart",
                "Name[fi]": "Ace Jones, Thomas Baumgart",
                "Name[fr]": "Ace Jones,Thomas Baumgart",
                "Name[gl]": "Ace Jones,Thomas Baumgart",
                "Name[ia]": "Ace Jones,Thomas Baumgart",
                "Name[it]": "Ace Jones,Thomas Baumgart",
                "Name[ko]": "Ace Jones,Thomas Baumgart",
                "Name[nl]": "Ace Jones,Thomas Baumgart",
                "Name[pl]": "Ace Jones,Thomas Baumgart",
                "Name[pt]": "Ace Jones,Thomas Baumgart",
                "Name[pt_BR]": "Ace Jones,Thomas Baumgart",
                "Name[ru]": "Ace Jones,Thomas Baumgart",
                "Name[sk]": "Ace Jones,Thomas Baumgart",
                "Name[sl]": "Ace Jones,Thomas Baumgart",
                "Name[sv]": "Ace Jones,Thomas Baumgart",
                "Name[uk]": "Ace Jones,Thomas Baumgart",
                "Name[x-test]": "xxAce Jones,Thomas Baumgartxx",
                "Name[zh_CN]": "Ace Jones,Thomas Baumgart"
            }
        ],
        "Description": "Add OFX importing to KMyMoney",
        "Description[ca@valencia]": "Afig la importació des d'OFX al KMyMoney",
        "Description[ca]": "Afegeix la importació des d'OFX al KMyMoney",
        "Description[de]": "Fügt OFX-Import zu KMyMoney hinzu",
        "Description[en_GB]": "Add OFX importing to KMyMoney",
        "Description[es]": "Añade importación OFX a KMyMoney",
        "Description[et]": "KMyMoney OFX importimine",
        "Description[eu]": "OFX inportazioa gehitzen dio KMyMoneyri ",
        "Description[fi]": "Lisää OFX-tuonti KMyMoney-ohjelmaan",
        "Description[fr]": "Ajoute l'importation « OFX » à KMyMoney",
        "Description[gl]": "Engadir a posibilidade de importar OFX en KMyMoney",
        "Description[it]": "Aggiunge l'importazione OFX a KMymoney",
        "Description[ko]": "KMyMoney에 OFX 가져오기 추가",
        "Description[nl]": "Voeg OFX importeren toe aan KMyMoney",
        "Description[pl]": "Dodaje importowanie OFX do KMyMoney",
        "Description[pt]": "Adição da importação de OFX para o KMyMoney",
        "Description[pt_BR]": "Adiciona importação OFX no KMyMoney",
        "Description[sk]": "Pridať OFX import do KMyMoney",
        "Description[sl]": "Doda uvoz OFX v KMyMoney",
        "Description[sv]": "Lägg till OFX-import till KMyMoney",
        "Description[uk]": "Імпортування даних OFX у KMyMoney",
        "Description[x-test]": "xxAdd OFX importing to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加 QFX 导入服务",
        "EnabledByDefault": true,
        "Icon": "network-connect",
        "Id": "ofximporter",
        "License": "GPL",
        "Name": "OFX Importer",
        "Name[ca@valencia]": "Importador d'OFX",
        "Name[ca]": "Importador d'OFX",
        "Name[cs]": "Importér OXF",
        "Name[de]": "OFX-Import",
        "Name[en_GB]": "OFX Importer",
        "Name[es]": "Importador OFX",
        "Name[et]": "OFX importija",
        "Name[eu]": "OFX inportatzailea",
        "Name[fi]": "OFX-tuoja",
        "Name[fr]": "Importateur OFX",
        "Name[gl]": "Importador de OFX",
        "Name[ia]": "Importator de OFX",
        "Name[it]": "Strumento di importazione OFX",
        "Name[ko]": "OFX 가져오기 도구",
        "Name[nl]": "QFX-importeren",
        "Name[pl]": "Importer OFX",
        "Name[pt]": "Importação de OFX",
        "Name[pt_BR]": "Importador OFX",
        "Name[ru]": "Импорт OFX",
        "Name[sk]": "OFX Importer",
        "Name[sl]": "Uvoznik OFX",
        "Name[sv]": "QFX-import",
        "Name[uk]": "Інструмент імпортування OFX",
        "Name[x-test]": "xxOFX Importerxx",
        "Name[zh_CN]": "OFX 导入工具",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
